@@ -1410,7 +1410,7 @@ fallback_pair_tablet_mode(struct evdev_device *keyboard,
 		return;
 
 	evdev_log_debug(keyboard,
-			"tablet_mode_switch: paired %s<->%s\n",
+			"tablet-mode: paired %s<->%s\n",
 			keyboard->devname,
 			tablet_mode_switch->devname);
 
